from __future__ import annotations

from dataclasses import dataclass


@dataclass
class DeviceInfo:
    type: int
    name: str
    version: int
    is_degree: bool | None = None
    tmp_state: int | None = None
    hum_state: int | None = None
    vpd_state: int | None = None
    choose_port: int | None = None
    tmp: float | None = None
    hum: float | None = None
    vpd: float | None = None
    fan_type: int | None = None
    fan_state: int | None = None
    fan: int | None = None
    work_type: int | None = None
    level_on: int | None = None
    level_off: int | None = None



from enum import Enum

MANUFACTURER_ID = 2306

POSSIBLE_WRITE_CHARACTERISTIC_UUIDS = [
    "70D51001-2C7F-4E75-AE8A-D758951CE4E0",
    "0000ff01-0000-1000-8000-00805f9b34fb",
]
POSSIBLE_READ_CHARACTERISTIC_UUIDS = [
    "70D51002-2C7F-4E75-AE8A-D758951CE4E0",
    "0000ff02-0000-1000-8000-00805f9b34fb",
]


class CallbackType(Enum):
    """Callback type."""

    NOTIFICATION = 1
    UPDATE_RESPONSE = 2



from __future__ import annotations

__version__ = "0.4.0"


from .const import CallbackType
from .device import ACInfinityController
from .models import DeviceInfo
from .protocol import parse_manufacturer_data

__all__ = [
    "ACInfinityController",
    "CallbackType",
    "DeviceInfo",
    "parse_manufacturer_data",
]
